%% Simscape Multibody Parts Library
%
% This library provides examples of parameterized parts Simscape Multibody. They
% simplify the assembly of mechanisms.  Listed below are example models
% showing their use.
%
% <html>
% <tr><b><u>Library</u></b><br>
% <tr><a href="matlab:web('Multibody_Parts_Library_Overview.html');">Overview of Library</a><br>
% <tr><a href="matlab:web('Multibody_Parts_Library_Gear_Asy_Overview.html');">Overview of Gear Assemblies</a><br>
% <tr><a href="matlab:open_system('Multibody_Parts_Lib');">Open the Simscape Multibody Parts Library</a><br>
% <tr><br>
% <tr><b><u>Extrusion Examples </u></b><br>
% <tr>1. Circular Extrusion Assembly: <a href="matlab:open_system('sm_parts_test_tube_circ.slx');"> Model</a>, <a href="matlab:web('sm_parts_test_tube_circ.html');">Documentation</a><br>
% <tr>2. Box Extrusion Assembly: <a href="matlab:open_system('sm_parts_test_tube_box.slx');"> Model</a>, <a href="matlab:web('sm_parts_test_tube_box.html');">Documentation</a><br>
% <tr>3. Elliptical Tube Assembly: <a href="matlab:open_system('sm_parts_test_tube_ell.slx');"> Model</a>, <a href="matlab:web('sm_parts_test_tube_ell.html');">Documentation</a><br>
% <tr><br>
% <tr><b><u>Gear Examples </u></b><br>
% <tr>1. Common Gear Assembly Testrig: <a href="matlab:open_system('sm_common_gear_assembly_testrig.slx');"> Model</a>, <a href="matlab:web('sm_common_gear_assembly_testrig.html');">Documentation</a><br>
% <tr>2. Planetary Gear Testrig: <a href="matlab:open_system('sm_planetary_gear_testrig.slx');"> Model</a>, <a href="matlab:web('sm_planetary_gear_testrig.html');">Documentation</a><br>
% <tr>3. Bevel Gear Assembly Testrig: <a href="matlab:open_system('sm_bevel_gear_assembly_testrig.slx');"> Model</a>, <a href="matlab:web('sm_bevel_gear_assembly_testrig.html');">Documentation</a><br>
% <tr>4. Double Bevel Gear Assembly Testrig: <a href="matlab:open_system('sm_bevel_gear_2x_assembly_testrig.slx');"> Model</a>, <a href="matlab:web('sm_bevel_gear_2x_assembly_testrig.html');">Documentation</a><br>
% <tr>5. Four-Sided Bevel Gear Assembly Testrig: <a href="matlab:open_system('sm_bevel_gear_4x_closed_assembly_testrig.slx');"> Model</a>, <a href="matlab:web('sm_bevel_gear_4x_closed_assembly_testrig.html');">Documentation</a><br>
% <tr>6. Rack and Pinion Assembly Testrig: <a href="matlab:open_system('sm_rack_and_pinion_assembly_testrig.slx');"> Model</a>, <a href="matlab:web('sm_rack_and_pinion_assembly_testrig.html');">Documentation</a><br>
% <tr>7. Worm Gear Assembly Testrig: <a href="matlab:open_system('sm_worm_gear_assembly_testrig.slx');"> Model</a>, <a href="matlab:web('sm_worm_gear_assembly_testrig.html');">Documentation</a><br>
% <tr>8. Worm Gear Constraints with CAD Parts: <a href="matlab:open_system('sm_worm_gear_constraints_CAD.slx');"> Model</a>, <a href="matlab:web('sm_worm_gear_constraints_CAD.html');">Documentation</a><br>
% <tr>9. Lead Screw Actuation Torque: <a href="matlab:open_system('sm_lead_screw_actuation_torque.slx');"> Model</a>, <a href="matlab:web('sm_lead_screw_actuation_torque.html');">Documentation</a><br>
% <tr>10. Lead Screw with Friction: <a href="matlab:open_system('sm_lead_screw_friction.slx');"> Model</a>, <a href="matlab:web('sm_lead_screw_friction.html');">Documentation</a><br>
% <tr>11. Open Differential: <a href="matlab:open_system('sm_open_differential_testrig.slx');"> Model</a>, <a href="matlab:web('sm_open_differential_testrig.html');">Documentation</a><br>
% <tr><br>
% <tr><b><u>Linkage Examples</u></b><br>
% <tr>1. Four Bar Linkage: <a href="matlab:open_system('sm_links_4bar.slx');"> Model</a>, <a href="matlab:web('sm_links_4bar.html');">Documentation</a><br>
% <tr>2. Slider-Crank Linkage: <a href="matlab:open_system('sm_links_slider_crank.slx');"> Model</a>, <a href="matlab:web('sm_links_slider_crank.html');">Documentation</a><br>
% <tr>3. Five-Bar Linkage Stamping Mechanism: <a href="matlab:open_system('sm_links_5bar_stamp.slx');"> Model</a>, <a href="matlab:web('sm_links_5bar_stamp.html');">Documentation</a><br>
% <tr><br>
% <tr><b><u>Pulley Examples</u></b><br>
% <tr>1. Three Connected Pulleys: <a href="matlab:open_system('sm_pulleys_3pulleys.slx');"> Model</a>, <a href="matlab:web('sm_pulleys_3pulleys.html');">Documentation</a><br>
% <tr>2. Cable-Driven XY Table with Cross Base: <a href="matlab:cd([SPL_HomeDir filesep 'Examples' filesep 'Pulleys' filesep 'XY_Table_Cross']);startup_sm_pulleys_xytable_cross;"> Model</a>, <a href="matlab:web('sm_pulleys_xytable_cross.html');">Documentation</a><br>
% <tr><br>
% <tr><b><u>Applications </u></b><br>
% <tr>1. Water Powered Lift: <a href="matlab:cd([SPL_HomeDir filesep 'Examples' filesep 'Gears' filesep 'Water_Lift']);startup_sm_water_powered_lift;"> Model</a>, <a href="matlab:web('sm_water_powered_lift.html');">Documentation</a><br>
% <tr>2. Linear Transport System: <a href="matlab:cd([SPL_HomeDir filesep 'Examples' filesep 'Extrusions' filesep 'Conveyors' filesep 'XTS_1']);startup_xts_system;"> Model</a>, <a href="matlab:web('xts_system.html');">Documentation</a><br>
% </html>
% 
% Copyright 2017-2019 The MathWorks(TM), Inc.
